.. _index:


Cellsino is a Python library for generating sinograms (phase and fluorescence)
of cell phantoms for testing tomographic reconstruction algorithms.
This is the documentation of cellsino version |release|.


Documentation
=============

.. toctree::
   :maxdepth: 4

   sec_introduction
   sec_getting_started
   sec_examples
   sec_code_reference

.. toctree::
   :maxdepth: 1

   sec_changelog
   zsec_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
